class PurchaseController < ApplicationController

  # Make sure that a user logs in before doing any action here
  before_filter :authorize

  def index
    redirect_to :action => :begin
  end

  def list
    @purchase_pages, @purchase = paginate :purchases, :per_page => 100
  end

  def begin
    # enter a customer id here
    render :action => 'begin'
    session[:total] = 0.00
    session[:items] = []
  end

  def customer_ok
    if Customer.find_by_id(params[:customer_id])
      session[:customer_id] = params[:customer_id]
      redirect_to :action => :menu
    else
      flash[:error] = "Customer ID is invalid"
      redirect_to :action => :begin
    end
  end

  def menu
    @customer = Customer.find_by_id(session[:customer_id])
    @total_price = session[:total]
    @items = session[:items]
    render :action => 'menu'
  end

  def rent_begin
    render :action => 'rent_begin'
  end

  def rent_validate
    @customer = Customer.find_by_id(session[:customer_id])
    @rentable = Rentable.find_by_id(params[:rentable_id])

    if @customer.nil?
      flash[:error] = "Customer ID is invalid"
      redirect_to :action => :begin
      return
    end

    if @rentable.nil?
      flash[:error] = "Rentable ID is invalid"
      redirect_to :action => :rent_begin
      return
    end

    if @rentable.checkedout?
      flash[:error] = "This #{@rentable.type} is already checked out!"
      redirect_to :action => :rent_begin
      return
    end

    # Check Rentable Policies
    @maxvideos = RentablePolicy.find_by_name("MaxVideos")
    if @rentable.class == Video and @customer.checked_out_videos >= @maxvideos.value
      flash[:error] = "#{@maxvideos.description} LIMIT REACHED"
      redirect_to :action => :rent_begin
      return
    end

    @maxgames = RentablePolicy.find_by_name("MaxGames")
    if @rentable.class == Game and @customer.checked_out_games >= @maxgames.value
      flash[:error] = "#{@maxgames.description} LIMIT REACHED"
      redirect_to :action => :rent_begin
      return
    end

    @maxoverduevideos = RentablePolicy.find_by_name("MaxOverdueVideos")
    if @rentable.class == Video and @customer.overdue_videos >= @maxoverduevideos.value
      flash[:error] = "#{@maxoverduevideos.description} LIMIT REACHED"
      redirect_to :action => :rent_begin
      return
    end

    @maxoverduegames = RentablePolicy.find_by_name("MaxOverdueGames")
    if @rentable.class == Game and @customer.overdue_games >= @maxoverduegames.value
      flash[:error] = "#{@maxoverduegames.description} LIMIT REACHED"
      redirect_to :action => :rent_begin
      return
    end

    # Check out the item
    checkout = Coitem.new
    checkout.customer = @customer
    checkout.rentable = @rentable
    checkout.out_date = Time.now.to_date
    checkout.due_date = @rentable.due_date
    checkout.save!

    # Actually record the purchase
    purchase = RentablePurchase.new
    purchase.customer_id = session[:customer_id]
    purchase.date = Time.now.to_date
    purchase.price = @rentable.calculated_price
    purchase.rentable = @rentable
    purchase.save!

    # Add te session variables
    session[:total] += @rentable.calculated_price
    session[:items].push @rentable

    flash[:notice] = "Successfully made purchase"
    redirect_to :action => :menu
  end

  def buy_begin
    render :action => 'buy_begin'
  end

  def buy_validate
    @customer = Customer.find_by_id(session[:customer_id])
    @merchandise = Merchandise.find_by_id(params[:merchandise_id])
  
    if @customer.nil?
      flash[:error] = "Customer ID is invalid"
      redirect_to :action => :begin
      return
    end

    if @merchandise.nil?
      flash[:error] = "Merchandise ID is invalid"
      redirect_to :action => :buy_begin
      return
    end

    if @merchandise.quantity < 1
      flash[:error] = "The system thinks we are out of this merchandise item!"
      redirect_to :action => :buy_begin
      return
    end

    # Actually record the purchase
    purchase = MerchandisePurchase.new
    purchase.customer_id = session[:customer_id]
    purchase.date = Time.now.to_date
    purchase.price = @merchandise.price
    purchase.merchandise = @merchandise
    purchase.quantity = 1
    @merchandise.quantity -= 1

    # Add to session variables
    session[:total] += @merchandise.price
    session[:items].push @merchandise

    # Save both the merchandise (we changed the quantity) and the purchase to the log
    @merchandise.save!
    purchase.save!

    flash[:notice] = "Successfully made purchase"
    redirect_to :action => :menu
  end
end
